==> swibots-1.4.11b0-py3-none-any.whl: swibots/api/callback/Button.py <==
from typing import Optional, List, Union

from swibots.utils.types import JSONDict
from .types import Component, Text, Icon


class Button(Component):
    type = "action_button"

    def __init__(
        self,
        text: Union[str, Text],
        icon: Union[str, Icon] = "",
        callback_data: Optional[str] = None,
        **kwargs
    ):
        if isinstance(text, str):
            text = Text(text)
        self.text = text
        if isinstance(icon, str):
            icon = Icon(icon)
        self.icon = icon
        self.callback_data = callback_data
        self.action = kwargs.get("action")
        self.url = kwargs.get("url")
        self.file_name = kwargs.get("downloadFileName")

    def to_json(self):
        data = {
            "type": self.type,
            "text": self.text.to_json() if self.text else None,
            "callbackData": self.callback_data if self.callback_data else None,
        }
        if self.icon:
            data["icon"] = self.icon.to_json()
        if self.url:
            data["url"] = self.url
        if self.action:
            data["action"] = self.action
        if self.file_name:
            data["downloadFileName"] = self.file_name
        return data


class DownloadButton(Button):
    def __init__(
        self,
        download_url: str,
        file_name: str,
        text: str | Text = "Download",
        icon: str | Icon = "",
        callback_data: str = None
    ):
        super().__init__(
            text, icon, url=download_url, file_name=file_name, action="download",
            callback_data=callback_data
        )


# TODO:
class ShareButton(Button):
    ...


class ButtonGroup(Component):
    type = "button_group"

    def __init__(self, buttons: List[Button]):
        self.buttons = buttons

    def to_json(self):
        return {
            "type": self.type,
            "buttons": [button.to_json() for button in self.buttons],
        }

==> swibots-1.4.22b0-py3-none-any.whl: swibots/api/callback/Button.py <==
from typing import Optional, List, Union

from swibots.utils.types import JSONDict
from .types import Component, Text, Icon


class Button(Component):
    type = "action_button"

    def __init__(
        self,
        text: Union[str, Text],
        icon: Union[str, Icon] = "",
        callback_data: Optional[str] = None,
        color: str = None,
        **kwargs
    ):
        if isinstance(text, str):
            text = Text(text)
        self.text = text
        if isinstance(icon, str):
            icon = Icon(icon)
        self.icon = icon
        self.callback_data = callback_data
        self.color = color
        self.clipboard = kwargs.get("clipboard")
        self.action = kwargs.get("action")
        self.url = kwargs.get("url")
        self.file_name = kwargs.get("downloadFileName")

    def to_json(self):
        data = {
            "type": self.type,
            "text": self.text.to_json() if self.text else None,
            "callbackData": self.callback_data if self.callback_data else None,
            "color": self.color,
        }
        if self.icon:
            data["icon"] = self.icon.to_json()
        if self.url:
            data["url"] = self.url
        if self.action:
            data["action"] = self.action
        if self.file_name:
            data["downloadFileName"] = self.file_name
        if self.clipboard:
            data["clipboard"] = True
        return data


class DownloadButton(Button):
    def __init__(
        self,
        download_url: str,
        file_name: str,
        text: str | Text = "Download",
        icon: str | Icon = "",
        callback_data: str = None,
    ):
        super().__init__(
            text,
            icon,
            url=download_url,
            file_name=file_name,
            action="download",
            callback_data=callback_data,
        )


# TODO:
class ShareButton(Button): ...


class ButtonGroup(Component):
    type = "button_group"

    def __init__(self, buttons: List[Button]):
        self.buttons = buttons

    def to_json(self):
        return {
            "type": self.type,
            "buttons": [button.to_json() for button in self.buttons],
        }


class StickyHeader(Component):
    type = "sticky_header"

    def __init__(
        self, text: str, color: str = None, callback_data: str = None, icon: Icon = None
    ):
        self.text = text
        self.color = color
        self.callback_data = callback_data
        self.icon = icon

    def to_json(self):
        return {
            "type": self.type,
            "text": self.text,
            "color": self.color,
            "callbackData": self.callback_data,
            "icon": self.icon.to_json() if self.icon else None,
        }
